==> ckeditor_4.10.0+dfsg.orig.tar.xz: ckeditor-dev-4.10.0/plugins/forms/lang/fa.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'fa', {
	button: {
		title: 'ویژگی​های دکمه',
		text: 'متن (مقدار)',
		type: 'نوع',
		typeBtn: 'دکمه',
		typeSbm: 'ثبت',
		typeRst: 'بازنشانی (Reset)'
	},
	checkboxAndRadio: {
		checkboxTitle: 'ویژگی​های خانهٴ گزینه​ای',
		radioTitle: 'ویژگی​های دکمهٴ رادیویی',
		value: 'مقدار',
		selected: 'برگزیده',
		required: 'Required' // MISSING
	},
	form: {
		title: 'ویژگی​های فرم',
		menu: 'ویژگی​های فرم',
		action: 'رویداد',
		method: 'متد',
		encoding: 'رمزنگاری'
	},
	hidden: {
		title: 'ویژگی​های فیلد پنهان',
		name: 'نام',
		value: 'مقدار'
	},
	select: {
		title: 'ویژگی​های فیلد چندگزینه​ای',
		selectInfo: 'اطلاعات',
		opAvail: 'گزینه​های دردسترس',
		value: 'مقدار',
		size: 'اندازه',
		lines: 'خطوط',
		chkMulti: 'گزینش چندگانه فراهم باشد',
		required: 'Required', // MISSING
		opText: 'متن',
		opValue: 'مقدار',
		btnAdd: 'افزودن',
		btnModify: 'ویرایش',
		btnUp: 'بالا',
		btnDown: 'پائین',
		btnSetValue: 'تنظیم به عنوان مقدار برگزیده',
		btnDelete: 'پاککردن'
	},
	textarea: {
		title: 'ویژگی​های ناحیهٴ متنی',
		cols: 'ستون​ها',
		rows: 'سطرها'
	},
	textfield: {
		title: 'ویژگی​های فیلد متنی',
		name: 'نام',
		value: 'مقدار',
		charWidth: 'پهنای نویسه',
		maxChars: 'بیشینهٴ نویسه​ها',
		required: 'Required', // MISSING
		type: 'نوع',
		typeText: 'متن',
		typePass: 'گذرواژه',
		typeEmail: 'ایمیل',
		typeSearch: 'جستجو',
		typeTel: 'شماره تلفن',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/forms/lang/fa.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'fa', {
	button: {
		title: 'ویژگی​‌های دکمه',
		text: 'متن (مقدار)',
		type: 'نوع',
		typeBtn: 'دکمه',
		typeSbm: 'ثبت',
		typeRst: 'بازنشانی (Reset)'
	},
	checkboxAndRadio: {
		checkboxTitle: 'ویژگی​های خانهٴ گزینه​ای',
		radioTitle: 'ویژگی​های دکمهٴ رادیویی',
		value: 'مقدار',
		selected: 'برگزیده',
		required: 'ضروری'
	},
	form: {
		title: 'ویژگی‌​های فرم',
		menu: 'ویژگی​‌های فرم',
		action: 'رویداد',
		method: 'متد',
		encoding: 'رمزنگاری'
	},
	hidden: {
		title: 'ویژگی‌​های فیلد پنهان',
		name: 'نام',
		value: 'مقدار'
	},
	select: {
		title: 'ویژگی‌​های فیلد چندگزینه‌​ای',
		selectInfo: 'اطلاعات',
		opAvail: 'گزینه​های دردسترس',
		value: 'مقدار',
		size: 'اندازه',
		lines: 'خطوط',
		chkMulti: 'گزینش چندگانه فراهم باشد',
		required: 'ضروری',
		opText: 'متن',
		opValue: 'مقدار',
		btnAdd: 'افزودن',
		btnModify: 'ویرایش',
		btnUp: 'بالا',
		btnDown: 'پائین',
		btnSetValue: 'تنظیم به عنوان مقدار برگزیده',
		btnDelete: 'پاک‌کردن'
	},
	textarea: {
		title: 'ویژگی​های ناحیهٴ متنی',
		cols: 'ستون​ها',
		rows: 'سطرها'
	},
	textfield: {
		title: 'ویژگی‌​های فیلد متنی',
		name: 'نام',
		value: 'مقدار',
		charWidth: 'پهنای نویسه',
		maxChars: 'حداکثر کارکتر',
		required: 'ضروری',
		type: 'نوع',
		typeText: 'متن',
		typePass: 'گذرواژه',
		typeEmail: 'ایمیل',
		typeSearch: 'جستجو',
		typeTel: 'شماره تلفن',
		typeUrl: 'URL'
	}
} );
